@@ -1,3 +1,27 @@
+/*
+ @licstart  The following is the entire license notice for the JavaScript code in this file.
+
+ The MIT License (MIT)
+
+ Copyright (C) 1997-2020 by Dimitri van Heesch
+
+ Permission is hereby granted, free of charge, to any person obtaining a copy of this software
+ and associated documentation files (the "Software"), to deal in the Software without restriction,
+ including without limitation the rights to use, copy, modify, merge, publish, distribute,
+ sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
+ furnished to do so, subject to the following conditions:
+
+ The above copyright notice and this permission notice shall be included in all copies or
+ substantial portions of the Software.
+
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
+ BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+ NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
+ DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+ @licend  The above is the entire license notice for the JavaScript code in this file
+*/
 var NAVTREE =
 [
   [ "Doxygen", "index.html", [
@@ -29,8 +53,7 @@ var NAVTREE =
         ] ],
         [ "Comment blocks in Python", "docblocks.html#pythonblocks", null ],
         [ "Comment blocks in VHDL", "docblocks.html#vhdlblocks", null ],
-        [ "Comment blocks in Fortran", "docblocks.html#fortranblocks", null ],
-        [ "Comment blocks in Tcl", "docblocks.html#tclblocks", null ]
+        [ "Comment blocks in Fortran", "docblocks.html#fortranblocks", null ]
       ] ],
       [ "Anatomy of a comment block", "docblocks.html#docstructure", null ]
     ] ],
@@ -43,6 +66,7 @@ var NAVTREE =
         [ "Code Blocks", "markdown.html#md_codeblock", null ],
         [ "Horizontal Rulers", "markdown.html#md_rulers", null ],
         [ "Emphasis", "markdown.html#md_emphasis", null ],
+        [ "Strikethrough", "markdown.html#md_strikethrough", null ],
         [ "code spans", "markdown.html#md_codespan", null ],
         [ "Links", "markdown.html#md_links", [
           [ "Inline Links", "markdown.html#md_inlinelinks", null ],
@@ -61,7 +85,7 @@ var NAVTREE =
         [ "Including Markdown files as pages", "markdown.html#md_page_header", null ],
         [ "Treatment of HTML blocks", "markdown.html#md_html_blocks", null ],
         [ "Code Block Indentation", "markdown.html#mddox_code_blocks", null ],
-        [ "Emphasis limits", "markdown.html#mddox_emph_spans", null ],
+        [ "Emphasis and strikethrough limits", "markdown.html#mddox_emph_spans", null ],
         [ "Code Spans Limits", "markdown.html#mddox_code_spans", null ],
         [ "Lists Extensions", "markdown.html#mddox_lists", null ],
         [ "Use of asterisks", "markdown.html#mddox_stars", null ],
@@ -111,7 +135,7 @@ var NAVTREE =
       [ "When I set EXTRACT_ALL to NO none of my functions are shown in the documentation.", "faq.html#faq_extract_all", null ],
       [ "My file with a custom extension is not parsed (properly) (anymore).", "faq.html#faq_ext_mapping", null ],
       [ "How can I make doxygen ignore some code fragment?", "faq.html#faq_code", null ],
-      [ "How can I change what is after the <code>#include</code> in the class documentation?", "faq.html#faq_code_inc", null ],
+      [ "How can I change what is after the #include in the class documentation?", "faq.html#faq_code_inc", null ],
       [ "How can I use tag files in combination with compressed HTML?", "faq.html#faq_chm", null ],
       [ "I don't like the quick index that is put above each HTML page, what do I do?", "faq.html#faq_html", null ],
       [ "The overall HTML output looks different, while I only wanted to use my own html header file", "faq.html#faq_html_header", null ],
@@ -120,12 +144,13 @@ var NAVTREE =
       [ "Doxygen automatically generates a link to the class MyClass somewhere in the running text.  How do I prevent that at a certain place?", "faq.html#faq_class", null ],
       [ "My favorite programming language is X. Can I still use doxygen?", "faq.html#faq_pgm_X", null ],
       [ "Help! I get the cryptic message \"input buffer overflow, can't enlarge buffer because scanner uses REJECT\"", "faq.html#faq_lex", null ],
-      [ "When running make in the latex dir I get \"TeX capacity exceeded\". Now what?", "faq.html#faq_latex", null ],
+      [ "When running make in the latex directory I get \"TeX capacity exceeded\". Now what?", "faq.html#faq_latex", null ],
       [ "Why are dependencies via STL classes not shown in the dot graphs?", "faq.html#faq_stl", null ],
       [ "I have problems getting the search engine to work with PHP5 and/or windows", "faq.html#faq_search", null ],
       [ "Can I configure doxygen from the command line?", "faq.html#faq_cmdline", null ],
       [ "How did doxygen get its name?", "faq.html#faq_name", null ],
-      [ "What was the reason to develop doxygen?", "faq.html#faq_why", null ]
+      [ "What was the reason to develop doxygen?", "faq.html#faq_why", null ],
+      [ "How to prevent interleaved output", "faq.html#faq_bin", null ]
     ] ],
     [ "Troubleshooting", "trouble.html", [
       [ "Known Problems", "trouble.html#knowproblems", null ],
@@ -136,7 +161,21 @@ var NAVTREE =
     [ "Doxygen usage", "doxygen_usage.html", [
       [ "Fine-tuning the output", "doxygen_usage.html#doxygen_finetune", null ]
     ] ],
-    [ "Doxywizard usage", "doxywizard_usage.html", null ],
+    [ "Doxywizard usage", "doxywizard_usage.html", [
+      [ "Wizard tab", "doxywizard_usage.html#dw_wizard", [
+        [ "Project settings", "doxywizard_usage.html#dw_wizard_project", null ],
+        [ "Mode of operating", "doxywizard_usage.html#dw_wizard_mode", null ],
+        [ "Output to produce", "doxywizard_usage.html#dw_wizard_output", null ],
+        [ "Diagrams to generate", "doxywizard_usage.html#dw_wizard_diagrams", null ]
+      ] ],
+      [ "Expert tab", "doxywizard_usage.html#dw_expert", null ],
+      [ "Run tab", "doxywizard_usage.html#dw_run", null ],
+      [ "Menu options", "doxywizard_usage.html#dw_menu", [
+        [ "File menu", "doxywizard_usage.html#dw_menu_file", null ],
+        [ "Settings menu", "doxywizard_usage.html#dw_menu_settings", null ],
+        [ "Help menu", "doxywizard_usage.html#dw_menu_help", null ]
+      ] ]
+    ] ],
     [ "Configuration", "config.html", [
       [ "Format", "config.html#config_format", null ],
       [ "Project related configuration options", "config.html#config_project", null ],
@@ -152,6 +191,7 @@ var NAVTREE =
       [ "Configuration options related to the XML output", "config.html#config_xml", null ],
       [ "Configuration options related to the DOCBOOK output", "config.html#config_docbook", null ],
       [ "Configuration options for the AutoGen Definitions output", "config.html#config_autogen", null ],
+      [ "Configuration options related to Sqlite3 output", "config.html#config_sqlite3", null ],
       [ "Configuration options related to the Perl module output", "config.html#config_perlmod", null ],
       [ "Configuration options related to the preprocessor", "config.html#config_preprocessor", null ],
       [ "Configuration options related to external references", "config.html#config_external", null ],
@@ -165,13 +205,18 @@ var NAVTREE =
       [ "\\hidecallgraph", "commands.html#cmdhidecallgraph", null ],
       [ "\\callergraph", "commands.html#cmdcallergraph", null ],
       [ "\\hidecallergraph", "commands.html#cmdhidecallergraph", null ],
+      [ "\\showrefby", "commands.html#cmdshowrefby", null ],
+      [ "\\hiderefby", "commands.html#cmdhiderefby", null ],
+      [ "\\showrefs", "commands.html#cmdshowrefs", null ],
+      [ "\\hiderefs", "commands.html#cmdhiderefs", null ],
       [ "\\category <name> [<header-file>] [<header-name>]", "commands.html#cmdcategory", null ],
       [ "\\class <name> [<header-file>] [<header-name>]", "commands.html#cmdclass", null ],
+      [ "\\concept <name>", "commands.html#cmdconcept", null ],
       [ "\\def <name>", "commands.html#cmddef", null ],
       [ "\\defgroup <name> (group title)", "commands.html#cmddefgroup", null ],
       [ "\\dir [<path fragment>]", "commands.html#cmddir", null ],
       [ "\\enum <name>", "commands.html#cmdenum", null ],
-      [ "\\example <file-name>", "commands.html#cmdexample", null ],
+      [ "\\example['{lineno}'] <file-name>", "commands.html#cmdexample", null ],
       [ "\\endinternal", "commands.html#cmdendinternal", null ],
       [ "\\extends <name>", "commands.html#cmdextends", null ],
       [ "\\file [<name>]", "commands.html#cmdfile", null ],
@@ -222,6 +267,7 @@ var NAVTREE =
       [ "\\date { date description }", "commands.html#cmddate", null ],
       [ "\\deprecated { description }", "commands.html#cmddeprecated", null ],
       [ "\\details { detailed description }", "commands.html#cmddetails", null ],
+      [ "\\noop ( text to be ignored )", "commands.html#cmdnoop", null ],
       [ "\\else", "commands.html#cmdelse", null ],
       [ "\\elseif (section-label)", "commands.html#cmdelseif", null ],
       [ "\\endcond", "commands.html#cmdendcond", null ],
@@ -232,7 +278,7 @@ var NAVTREE =
       [ "\\invariant { description of invariant }", "commands.html#cmdinvariant", null ],
       [ "\\note { text }", "commands.html#cmdnote", null ],
       [ "\\par [(paragraph title)] { paragraph }", "commands.html#cmdpar", null ],
-      [ "\\param [(dir)] <parameter-name> { parameter description }", "commands.html#cmdparam", null ],
+      [ "\\param '['dir']' <parameter-name> { parameter description }", "commands.html#cmdparam", null ],
       [ "\\parblock", "commands.html#cmdparblock", null ],
       [ "\\endparblock", "commands.html#cmdendparblock", null ],
       [ "\\tparam <template-parameter-name> { description }", "commands.html#cmdtparam", null ],
@@ -265,34 +311,42 @@ var NAVTREE =
       [ "\\secreflist", "commands.html#cmdsecreflist", null ],
       [ "\\endsecreflist", "commands.html#cmdendsecreflist", null ],
       [ "\\subpage <name> [\"(text)\"]", "commands.html#cmdsubpage", null ],
-      [ "\\tableofcontents", "commands.html#cmdtableofcontents", null ],
+      [ "\\tableofcontents['{'[option[:level]][,option[:level]]*'}']", "commands.html#cmdtableofcontents", null ],
       [ "\\section <section-name> (section title)", "commands.html#cmdsection", null ],
       [ "\\subsection <subsection-name> (subsection title)", "commands.html#cmdsubsection", null ],
       [ "\\subsubsection <subsubsection-name> (subsubsection title)", "commands.html#cmdsubsubsection", null ],
       [ "\\paragraph <paragraph-name> (paragraph title)", "commands.html#cmdparagraph", null ],
-      [ "\\dontinclude <file-name>", "commands.html#cmddontinclude", null ],
-      [ "\\include <file-name>", "commands.html#cmdinclude", null ],
+      [ "\\dontinclude['{lineno}'] <file-name>", "commands.html#cmddontinclude", null ],
+      [ "\\include['{'option'}'] <file-name>", "commands.html#cmdinclude", null ],
       [ "\\includelineno <file-name>", "commands.html#cmdincludelineno", null ],
+      [ "\\includedoc <file-name>", "commands.html#cmdincludedoc", null ],
       [ "\\line ( pattern )", "commands.html#cmdline", null ],
       [ "\\skip ( pattern )", "commands.html#cmdskip", null ],
       [ "\\skipline ( pattern )", "commands.html#cmdskipline", null ],
-      [ "\\snippet <file-name> ( block_id )", "commands.html#cmdsnippet", null ],
+      [ "\\snippet['{'option'}'] <file-name> ( block_id )", "commands.html#cmdsnippet", null ],
+      [ "\\snippetlineno <file-name> ( block_id )", "commands.html#cmdsnippetlineno", null ],
+      [ "\\snippetdoc <file-name> ( block_id )", "commands.html#cmdsnippetdoc", null ],
       [ "\\until ( pattern )", "commands.html#cmduntil", null ],
       [ "\\verbinclude <file-name>", "commands.html#cmdverbinclude", null ],
-      [ "\\htmlinclude <file-name>", "commands.html#cmdhtmlinclude", null ],
+      [ "\\htmlinclude [\"[block]\"] <file-name>", "commands.html#cmdhtmlinclude", null ],
       [ "\\latexinclude <file-name>", "commands.html#cmdlatexinclude", null ],
+      [ "\\rtfinclude <file-name>", "commands.html#cmdrtfinclude", null ],
+      [ "\\maninclude <file-name>", "commands.html#cmdmaninclude", null ],
+      [ "\\docbookinclude <file-name>", "commands.html#cmddocbookinclude", null ],
+      [ "\\xmlinclude <file-name>", "commands.html#cmdxmlinclude", null ],
       [ "\\a <word>", "commands.html#cmda", null ],
       [ "\\arg { item-description }", "commands.html#cmdarg", null ],
       [ "\\b <word>", "commands.html#cmdb", null ],
       [ "\\c <word>", "commands.html#cmdc", null ],
-      [ "\\code [ '{'<word>'}']", "commands.html#cmdcode", null ],
+      [ "\\code['{'<word>'}']", "commands.html#cmdcode", null ],
       [ "\\copydoc <link-object>", "commands.html#cmdcopydoc", null ],
       [ "\\copybrief <link-object>", "commands.html#cmdcopybrief", null ],
       [ "\\copydetails <link-object>", "commands.html#cmdcopydetails", null ],
       [ "\\docbookonly", "commands.html#cmddocbookonly", null ],
       [ "\\dot [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddot", null ],
+      [ "\\emoji \"name\"", "commands.html#cmdemoji", null ],
       [ "\\msc [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdmsc", null ],
-      [ "\\startuml [{file}] [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdstartuml", null ],
+      [ "\\startuml ['{'option[,option]'}'] [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdstartuml", null ],
       [ "\\dotfile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddotfile", null ],
       [ "\\mscfile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdmscfile", null ],
       [ "\\diafile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddiafile", null ],
@@ -310,12 +364,14 @@ var NAVTREE =
       [ "\\endverbatim", "commands.html#cmdendverbatim", null ],
       [ "\\endxmlonly", "commands.html#cmdendxmlonly", null ],
       [ "\\f$", "commands.html#cmdfdollar", null ],
+      [ "\\f(", "commands.html#cmdfrndopen", null ],
+      [ "\\f)", "commands.html#cmdfrndclose", null ],
       [ "\\f[", "commands.html#cmdfbropen", null ],
       [ "\\f]", "commands.html#cmdfbrclose", null ],
       [ "\\f{environment}{", "commands.html#cmdfcurlyopen", null ],
       [ "\\f}", "commands.html#cmdfcurlyclose", null ],
       [ "\\htmlonly [\"[block]\"]", "commands.html#cmdhtmlonly", null ],
-      [ "\\image <format> <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdimage", null ],
+      [ "\\image['{'option[,option]'}'] <format> <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdimage", null ],
       [ "\\latexonly", "commands.html#cmdlatexonly", null ],
       [ "\\manonly", "commands.html#cmdmanonly", null ],
       [ "\\li { item-description }", "commands.html#cmdli", null ],
@@ -335,6 +391,7 @@ var NAVTREE =
       [ "\\%", "commands.html#cmdperc", null ],
       [ "\\\"", "commands.html#cmdquot", null ],
       [ "\\.", "commands.html#cmdchardot", null ],
+      [ "\\=", "commands.html#cmdeq", null ],
       [ "\\::", "commands.html#cmddcolon", null ],
       [ "\\|", "commands.html#cmdpipe", null ],
       [ "\\--", "commands.html#cmdndash", null ],
@@ -342,6 +399,10 @@ var NAVTREE =
     ] ],
     [ "HTML Commands", "htmlcmds.html", null ],
     [ "XML Commands", "xmlcmds.html", null ],
+    [ "Emoji support", "emojisup.html", [
+      [ "Representation", "emojisup.html#emojirep", null ],
+      [ "Emoji image retrieval", "emojisup.html#emojiimage", null ]
+    ] ],
     [ "Internationalization", "langhowto.html", null ],
     [ "Perl Module Output", "perlmod.html", [
       [ "Usage", "perlmod.html#using_perlmod_fmt", null ],
@@ -354,7 +415,21 @@ var NAVTREE =
     [ "Perl Module Tree Nodes", "perlmod_tree.html", null ],
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
+      [ "1.9 Series", "changelog.html#log_1_9", [
+        [ "Release 1.9.2", "changelog.html#log_1_9_2", null ],
+        [ "Release 1.9.1", "changelog.html#log_1_9_1", null ],
+        [ "Release 1.9.0", "changelog.html#log_1_9_0", null ]
+      ] ],
       [ "1.8 Series", "changelog.html#log_1_8", [
+        [ "Release 1.8.20", "changelog.html#log_1_8_20", null ],
+        [ "Release 1.8.19", "changelog.html#log_1_8_19", null ],
+        [ "Release 1.8.18", "changelog.html#log_1_8_18", null ],
+        [ "Release 1.8.17", "changelog.html#log_1_8_17", null ],
+        [ "Release 1.8.16", "changelog.html#log_1_8_16", null ],
+        [ "Release 1.8.15", "changelog.html#log_1_8_15", null ],
+        [ "Release 1.8.14", "changelog.html#log_1_8_14", null ],
+        [ "Release 1.8.13", "changelog.html#log_1_8_13", null ],
+        [ "Release 1.8.12", "changelog.html#log_1_8_12", null ],
         [ "Release 1.8.11", "changelog.html#log_1_8_11", null ],
         [ "Release 1.8.10", "changelog.html#log_1_8_10", null ],
         [ "Release 1.8.9.1", "changelog.html#log_1_8_9_1", null ],
@@ -373,7 +448,12 @@ var NAVTREE =
         [ "Release 1.8.0", "changelog.html#log_1_8_0", null ]
       ] ],
       [ "1.7 Series", "changelog.html#log_1_7", null ],
-      [ "1.6 Series", "changelog.html#log_1_6", null ]
+      [ "1.6 Series", "changelog.html#log_1_6", null ],
+      [ "1.5 Series", "changelog.html#log_1_5", null ],
+      [ "1.4 Series", "changelog.html#log_1_4", null ],
+      [ "1.3 Series", "changelog.html#log_1_3", null ],
+      [ "1.2 Series", "changelog.html#log_1_2", null ],
+      [ "1.1 Series", "changelog.html#log_1_1", null ]
     ] ]
   ] ]
 ];
@@ -381,7 +461,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "arch.html",
-"docblocks.html#structuralcommands"
+"config.html#config_external"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
